function  [hFigHandle] = PlotLine(mX,mY,varargin)
%% Plot 2-D Line Figures
%
% This function creates a line plot with the properties defined in
% 'PlotProperties.mat'. For multiple plots within a single figure the
% 'fighandle' varargin parameter can be used.
% 
% Input Variables:
%   mX          : X-Axis Data 
%   mY          : Y-Axis Data 
% 
% varargin    : 
%   'title'         followed by 'title'
%   'xlabel'        followed by x-label
%   'ylabel'        followed by y-label
%   'legend'        followed by the legend for the line
%   'legendoff'     force legend off
%   'legendlocation' followed by the location of the legend
%
%   'filename'      followed by filename to write the file
%   'hold'          don't create a new figure, reuse the 'current'
%   'fighandle'     followed by handle, don't create a new figure, reuse handle
%   'subplot'       followed by the subplot arguments in a cell
%
%   'color'         followed by the line color
%   'colornr'       followed by colornr. Uses n-th entry of the colormap
%                   defined in PlotProperties
%   'linewidth'     followed by linewidth set the width of a line
%
%   'xlim'          followed by x limit [min max]
%   'ylim'          followed by y limit [min max]
%
%   'y2'            followed by data for axis two, adds secondary axes
%   'color2'        followed by the color of the second line
%
%   'xlog'          Set X Scala logarithmic
%
% Output Variables
%   FigHandle        The handle of the figure used
%
% SEE ALSO Visualisation.PlotDataSet Visualisation.PlotMap
% Visualisation.PlotSurf
%
% 30.11.2012 Marc Dirix
% 17.12.2013 Arne Kittlaus (Rasmus Cornelius)

%% Load default values
PlotProperties = Visualisation.GetPlotProperties;


nPrint = 0;
nNewFigure = 1;
colormap = PlotProperties.colorlist;
sColor = colormap(1,:);
sColor2 = colormap(mod(1,size(colormap,1))+1,:);
linestyle = PlotProperties.linestyle{1};
nLineWidth = PlotProperties.linewidth;
xLog = PlotProperties.xlog;
yLog = 0;
legendlocation = 'northeast';

if ~isempty(PlotProperties.xlim)
    xlimit = PlotProperties.xlim;
end
if ~isempty(PlotProperties.ylim)
    ylimit = PlotProperties.ylim;
end

for k = 1:length(varargin)
    if ischar(varargin{k})
        switch lower(varargin{k})
            case 'title'
                sTitle = varargin{k+1};
            case 'name'
                sName = varargin{k+1};
            case 'filename'
                nPrint = 1;
                sFilename = varargin{k+1};
            case 'hold'
                nNewFigure = 0;
            case 'color'
                sColor = varargin{k+1};
            case 'colornr'
                sColor = colormap(mod(varargin{k+1}-1,size(colormap,1))+1,:);
            case 'color2'
                sColor2 = varargin{k+1};
            case 'linestyle'
                linestyle = varargin{k+1};
            case 'linewidth'
                nLineWidth = varargin{k+1};
            case {'fighandle','handle'}
                if ishandle(varargin{k+1} ) && strcmp(get(varargin{k+1} ,'type'),'figure')
                    hFigHandle = varargin{k+1};
                    nNewFigure = 0;
                end
            case 'xlim'
                if ischar(varargin{k+1}) && strcmpi(varargin{k+1},'auto')
                    xlimit = [mX(1) mX(end)];   
                elseif length(varargin{k+1}) == 1
                    ylimit = [mX(1)-varargin{k+1} mX(end)+varargin{k+1}];
                else
                    xlimit = varargin{k+1};
                end
            case 'ylim'
                if ischar(varargin{k+1}) && strcmpi(varargin{k+1},'auto')
                    ylimit = [min(mY) max(mY)];
                elseif length(varargin{k+1}) == 1
                    ylimit = [min(mY)-varargin{k+1} max(mY)+varargin{k+1}];
                else
                    ylimit = varargin{k+1};
                end
            case 'xlabel'
                sxlabel = varargin{k+1};
            case 'ylabel'
                sylabel = varargin{k+1};
            case 'y2'
                mY2 = varargin{k+1};
            case 'xlog'
                xLog = 1;
            case 'ylog'
                yLog = 1;
            case 'legend'
                newLegend = varargin{k+1};
            case 'legendoff'
                hlegendOff = 1;
            case 'legendlocation'
                legendlocation = varargin{k+1};
            case 'subplot'
                clSubPlotArgs = varargin{k+1};
            case 'markersize'
                PlotProperties.MarkerSize = varargin{k+1};
        end
    end
end

if ~exist('sName','var')
    if exist('sTitle','var')
        sName = sTitle;
    else
        sName = 'Unnamed Figure';
    end
end

%Should we create a new figure, if not did we get a figure handle or should
%we reuse the last figure.

if nNewFigure == 1
    hFigHandle = figure('Color',PlotProperties.figurecolor,'Position',PlotProperties.defaultsize,'name',sName,'NumberTitle','off');
elseif exist('hFigHandle','var');
    hFigHandle = figure(hFigHandle);
else
    hFigHandle = gcf;
end

if exist('clSubPlotArgs','var')
    subplot(clSubPlotArgs{:});
end

if exist('newLegend','var')
    clDisplayName = {'DisplayName',newLegend};
else
    clDisplayName = {};
end
    
if ~exist('mY2','var')
    hH1 = plot(mX,mY,linestyle,'Color',sColor,'LineWidth',nLineWidth,clDisplayName{:});

    if exist('xlimit','var')
        xlim(xlimit);
    end
    if exist('ylimit','var')
        ylim(ylimit);
    end
%    if exist('hlegendOff','var')
%        set(get(get(hH1,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
%    end
else
    [hAx, hH1, hH2] = plotyy(mX,mY,mX,mY2,clDisplayName{:});
    if exist('xlimit','var')
        xlim(hAx(1),xlimit);
        xlim(hAx(2),xlimit);
    end
    set(hAx(2),'XTickLabel','') 
    set(hH1,'LineWidth',nLineWidth);
    set(hH2,'LineWidth',nLineWidth);
    set(hH1,'Color',sColor);
    set(hH2,'Color',sColor2);
%    if exist('hlegendOff','var')
%        set(get(get(hH1,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
%        set(get(get(hH2,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
%    end
end
%Put hold on if we want to reuse this figure.
hold on;
%hold all;

%% Titles and labels
%If there is an title display it.
if exist('sTitle','var')
    title(sTitle,'FontSize',PlotProperties.fontsizetitle,'color',PlotProperties.fontcolor,'fontname',PlotProperties.fontname);
end

if exist('sxlabel','var')
    xlabel(sxlabel,'FontSize',PlotProperties.fontsizeaxislabel,'fontname',PlotProperties.fontname);
elseif nNewFigure == 1
    xlabel('x','FontSize',PlotProperties.fontsizeaxislabel,'fontname',PlotProperties.fontname);
end

if exist('sylabel','var')
    ylabel(sylabel,'FontSize',PlotProperties.fontsizeaxislabel,'fontname',PlotProperties.fontname);
elseif nNewFigure == 1
    ylabel('y','FontSize',PlotProperties.fontsizeaxislabel,'fontname',PlotProperties.fontname);
end

%% Set Axes properties
if nNewFigure == 1
    set(gca,'FontSize',PlotProperties.fontsizeaxis,'xcolor',PlotProperties.fontcolor,'ycolor',PlotProperties.fontcolor,'Color',PlotProperties.axiscolor,'fontname',PlotProperties.fontname);
end

if xLog
    set(gca,'XScale','log');
end

if yLog
    set(gca,'YScale','log');
end

%% Add the correct Legends
%hNewLegend = 0;

if(exist('newLegend','var'))
    legend off;
    hNewLegend = legend(gca,'show');
    set(hNewLegend,'FontSize',PlotProperties.fontsizelegend,'TextColor',PlotProperties.fontcolor,'location',legendlocation,'fontname',PlotProperties.fontname);
end

if PlotProperties.axisequal
    axis equal;
end

%% Set grid
grid off;
switch PlotProperties.grid
    case 1
        grid on
        ax = gca;
    case 2
        grid minor
        ax = gca;
end

if isfield(PlotProperties,'GridColor')
    set(gca,'GridColor',PlotProperties.GridColor);
end

if isfield(PlotProperties,'GridAlpha')
    set(gca,'GridAlpha',PlotProperties.GridAlpha);
end

if isfield(PlotProperties,'MarkerSize')
    set(hH1,'MarkerSize',PlotProperties.MarkerSize);
    if exist('hH2','var')
        set(hH2,'MarkerSize',PlotProperties.MarkerSize);
    end
end

if nPrint == 1
    print(hFigHandle, '-djpeg','-r300', sFilename); 
end


end


